import debug from 'debug';
export declare enum CacheStatus {
    MISS = 0,
    PENDING = 1,
    HIT = 2
}
export declare type SsgCacheEntry<T> = {
    data: T;
    exp?: number;
};
export declare type SsgCacheGetOptions = {
    skipCache?: boolean;
    ttl?: number;
};
export interface SsgCacheStore {
}
export declare class SsgCache<S extends SsgCacheStore = SsgCacheStore> {
    static CACHE_DIR: string;
    static BUILD_ID_PATH: string;
    static BUILD_CACHE_PATH: string;
    static cache: Record<string, SsgCacheEntry<any>>;
    static cacheStatus: Record<string, CacheStatus>;
    static init(): Promise<string>;
    id: string;
    persistent: boolean;
    maxTimeout: number;
    debugInstance: debug.Debugger;
    constructor();
    path(keys?: string[], ext?: 'cache' | 'stat'): string;
    writeCacheStatus(keys: string[], status: CacheStatus): Promise<void>;
    readCacheStatus(keys: string[]): Promise<CacheStatus>;
    writeCache<T extends Extract<keyof S, string>>(keys: [T, ...string[]], data: S[T], ttl?: number): Promise<void>;
    readCache<T extends Extract<keyof S, string>>(keys: [T, ...string[]]): Promise<SsgCacheEntry<S[T]> | null>;
    waitForCacheToResolve<T extends Extract<keyof S, string>>(keys: [T, ...string[]]): Promise<CacheStatus>;
    wait(ms: number): Promise<void>;
    retry<P extends Promise<any>>(fn: () => P, maxTimes: number, ms?: number): Promise<any>;
    get<T extends Extract<keyof S, string>>(key: T | [T, ...string[]], fetcher: () => Promise<S[T]>, options?: SsgCacheGetOptions): Promise<S[T]>;
}
